package com.ruoyi.oa.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.oa.mapper.CmcProjectChangeMapper;
import com.ruoyi.oa.domain.CmcProjectChange;
import com.ruoyi.oa.service.ICmcProjectChangeService;

/**
 * cmc项目变更Service业务层处理
 * 
 * @author cmc
 * @date 2024-06-05
 */
@Service
public class CmcProjectChangeServiceImpl implements ICmcProjectChangeService 
{
    @Autowired
    private CmcProjectChangeMapper cmcProjectChangeMapper;

    /**
     * 查询cmc项目变更
     * 
     * @param changeId cmc项目变更主键
     * @return cmc项目变更
     */
    @Override
    public CmcProjectChange selectCmcProjectChangeByChangeId(String changeId)
    {
        return cmcProjectChangeMapper.selectCmcProjectChangeByChangeId(changeId);
    }

    /**
     * 查询cmc项目变更列表
     * 
     * @param cmcProjectChange cmc项目变更
     * @return cmc项目变更
     */
    @Override
    public List<CmcProjectChange> selectCmcProjectChangeList(CmcProjectChange cmcProjectChange)
    {
        return cmcProjectChangeMapper.selectCmcProjectChangeList(cmcProjectChange);
    }

    /**
     * 新增cmc项目变更
     * 
     * @param cmcProjectChange cmc项目变更
     * @return 结果
     */
    @Override
    public int insertCmcProjectChange(CmcProjectChange cmcProjectChange)
    {
        return cmcProjectChangeMapper.insertCmcProjectChange(cmcProjectChange);
    }

    /**
     * 修改cmc项目变更
     * 
     * @param cmcProjectChange cmc项目变更
     * @return 结果
     */
    @Override
    public int updateCmcProjectChange(CmcProjectChange cmcProjectChange)
    {
        return cmcProjectChangeMapper.updateCmcProjectChange(cmcProjectChange);
    }

    /**
     * 批量删除cmc项目变更
     * 
     * @param changeIds 需要删除的cmc项目变更主键
     * @return 结果
     */
    @Override
    public int deleteCmcProjectChangeByChangeIds(String[] changeIds)
    {
        return cmcProjectChangeMapper.deleteCmcProjectChangeByChangeIds(changeIds);
    }

    /**
     * 删除cmc项目变更信息
     * 
     * @param changeId cmc项目变更主键
     * @return 结果
     */
    @Override
    public int deleteCmcProjectChangeByChangeId(String changeId)
    {
        return cmcProjectChangeMapper.deleteCmcProjectChangeByChangeId(changeId);
    }
}
